Documentation
=============

The main classes in this package are :doc:`measurement` and :doc:`sigfig`. 

All other modules are in :doc:`util/index`, and are used to supplement and extend the functionality of the main classes.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   measurement
   sigfig
   util/index